bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.get_shape
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.get_shape